# Top X Advertisement Target Criterias used for YOU on Twitter

## intro

In this section, we're going to explore top X advertisement target criterias advertisers used for getting to YOU, on Twitter. These values are not of any specific category's, rather they are just consider as per their count of occurances.

## example

Here's a sample plot.

![top20AdTargetCriteriasUsedForAnjan_RoyOnTwitter](../plots/top20AdTargetCriteriasUsedForAnjan_RoyOnTwitter.png)
